@@ -279,4 +279,61 @@ def validate_package(config: Config) -> None:
             code=ErrorCode.PKG_STRUCTURE_INVALID,
             message="No tests directory found",
             fix_instructions=["Create tests directory"]
+        )
+
+def validate_package_structure(config: Config, workspace_dir: Optional[Path] = None) -> None:
+    """Validate package structure.
+    
+    Args:
+        config: Configuration object
+        workspace_dir: Optional workspace directory path
+    
+    Raises:
+        ReleaseError: If validation fails
+    """
+    workspace_dir = Path(workspace_dir or os.getcwd())
+    
+    # Check for required files
+    required_files = [
+        "README.md",
+        "LICENSE",
+        "CHANGELOG.md",
+        "pyproject.toml",
+        ".gitignore",
+    ]
+    
+    for file in required_files:
+        if not (workspace_dir / file).exists():
+            raise ReleaseError(
+                code=ErrorCode.PACKAGE_VALIDATION_ERROR,
+                message=f"Required file {file} not found",
+                fix_instructions=[f"Create {file} in project root"]
+            )
+    
+    # Check for src directory
+    src_dir = workspace_dir / "src"
+    if not src_dir.exists():
+        raise ReleaseError(
+            code=ErrorCode.SRC_DIR_NOT_FOUND,
+            message="src directory not found",
+            fix_instructions=["Create src directory in project root"]
+        )
+    
+    # Check for package directory
+    package_name = config.package_name.replace("-", "_")
+    package_dir = src_dir / package_name
+    if not package_dir.exists():
+        raise ReleaseError(
+            code=ErrorCode.PACKAGE_DIR_NOT_FOUND,
+            message=f"Package directory {package_name} not found in src/",
+            fix_instructions=[f"Create src/{package_name} directory"]
+        )
+    
+    # Check for __init__.py
+    init_file = package_dir / "__init__.py"
+    if not init_file.exists():
+        raise ReleaseError(
+            code=ErrorCode.INIT_PY_NOT_FOUND,
+            message=f"__init__.py not found in {package_dir}",
+            fix_instructions=[f"Create {init_file} file"]
         ) 
\ No newline at end of file
